aboutsummaryrefslogtreecommitdiff
path: root/src/options.h
diff options
context:
space:
mode:
authorToni Uhlig <matzeton@googlemail.com>2017-12-20 18:47:06 +0100
committerToni Uhlig <matzeton@googlemail.com>2017-12-20 18:47:06 +0100
commit3541aa3bf2e9090e2778e80a8dc20955bbb7654f (patch)
tree11bb82971cca87c3a54ee5724c230305df9b739b /src/options.h
parent0951e9a056dc791cd7a46014f1178b153829c48a (diff)
ptunnel-ng:
* improved option parsing/error printing * restrict tunnel destination ip/port only if the user wants it * print a warning if running on windows wihout pcap enabled * obey strict aliasing for pcap source * print available pcap devices if the user supplied an invalid one
Diffstat (limited to 'src/options.h')
-rw-r--r--src/options.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/src/options.h b/src/options.h
index bdd2061..d5023a4 100644
--- a/src/options.h
+++ b/src/options.h
@@ -25,10 +25,12 @@ struct options {
uint32_t given_proxy_ip;
/** Port the client listens on */
uint32_t tcp_listen_port;
- /** Forward/Proxy destination internet address */
+ /** restrict Forward/Proxy destination internet address */
+ int restrict_dst_ip;
char *given_dst_hostname;
uint32_t given_dst_ip;
- /** Forward/Proxy destination port */
+ /** restrict Forward/Proxy destination port */
+ int restrict_dst_port;
uint32_t given_dst_port;
/** Default maximum number of tunnels to support at once */
uint32_t max_tunnels;